from typing import Union, Mapping
from urllib import parse


def urljoin(base: str, url: str = '', params: Union[str, Mapping] = '') -> str:
    return '?'.join((parse.urljoin(base, url), parse.urlencode(params))).rstrip('?')


if __name__ == '__main__':
    print(urljoin('http://ww.sx/s/'))



from typing import Mapping, List, Dict

from pymongo import MongoClient


def insert_one(data: Mapping,
               collection: str, db: str, host: str, port: int, username: str, password: str,
               authSource: str) -> None:
    with MongoClient(host=host,
                     port=port,
                     username=username,
                     password=password,
                     authSource=authSource,
                     maxPoolSize=1) as MgClient:
        MgClient[db][collection].insert_one(data)


def find(condition: Mapping,
         collection: str, db: str, host: str, port: int, username: str, password: str,
         authSource: str) -> List[Dict]:
    with MongoClient(host=host,
                     port=port,
                     username=username,
                     password=password,
                     authSource=authSource,
                     maxPoolSize=1) as MgClient:
        return MgClient[db][collection].find(condition)
